@@ -1,5 +1,5 @@
 /******************************************************************************
-    (c) 1998-1999      P.J. Caulfield          patrick@tykepenguin.cix.co.uk
+    (c) 1998-2008      Christine Caulfield          christine.caulfield@googlemail.com
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,6 +74,7 @@ static void	dndir_usage(FILE *f)
     fprintf(f, "  -n           don't show header. Useful for shell scripts\n");
     fprintf(f, "  -c           Force single-column output on ttys (default for files)\n");
     fprintf(f, "  -t           Show total bytes/blocks\n");
+    fprintf(f, "  -T <secs>    Set connection timeout (default 60 seconds)\n");
     fprintf(f, "  -w <size>    width of multi-column output\n");
     fprintf(f, "  -f <size>    maximum width of filename field\n");
     fprintf(f, "  -? -h        display this help message\n");
@@ -82,7 +83,7 @@ static void	dndir_usage(FILE *f)
 
     fprintf(f, "\nExamples:\n\n");
     fprintf(f, " dndir -l 'myvax::*.*'\n");
-    fprintf(f, " dndir 'cluster\"patrick thecats\"::disk$users:[cats.pics]*.jpg;'\n");
+    fprintf(f, " dndir 'cluster\"christine thecats\"::disk$users:[cats.pics]*.jpg;'\n");
     fprintf(f, "\n");
 }
 
@@ -106,6 +107,7 @@ int main(int argc, char *argv[])
     int     printed;
     int     just_shown_header = 0;
     int     verbosity = 0;
+    int     connect_timeout = 60;
     unsigned long total = 0;
     unsigned int  filename_width = 18;
 
@@ -143,7 +145,7 @@ int main(int argc, char *argv[])
 // Get command-line options
     opterr = 0;
     optind = 0;
-    while ((opt=getopt(argc,argv,"?hvVvcepndlostbw:f:")) != EOF)
+    while ((opt=getopt(argc,argv,"?hvVvcepndlostbw:f:T:")) != EOF)
     {
 	switch(opt)
 	{
@@ -218,6 +220,10 @@ int main(int argc, char *argv[])
 	    term_width=atoi(optarg);
 	    break;
 
+	case 'T':
+	    connect_timeout=atoi(optarg);
+	    break;
+
 	case 'f':
 	    filename_width=atoi(optarg);
 	    break;
@@ -244,6 +250,7 @@ int main(int argc, char *argv[])
 
     dap_connection conn(verbosity);
     char dirname[256] = {'\0'};
+    conn.set_connect_timeout(connect_timeout);
     if (!conn.connect(argv[optind], dap_connection::FAL_OBJECT, dirname))
     {
 	fprintf(stderr, "%s\n", conn.get_error());
@@ -252,7 +259,7 @@ int main(int argc, char *argv[])
 
     // Default to a full wildcard if no filename is given. This will cope with
     // the situation where no directory is provided (node::) and where a
-    // directory (node::[patrick]) is provided. Logical names must end with
+    // directory (node::[christine]) is provided. Logical names must end with
     // a colon for this to happen or we will not be able to distinguish them
     // from filenames
     char lastchar('\0');
